@@ -75,7 +75,7 @@
 	/* end of COLOR vars */
 
 
-	char configFileName[256];
+	char *configFileName;
 
 
 	/*  properties vars */
@@ -116,20 +116,22 @@
 	gint drawTimeID, updateTimeID;
 
 	void removeSpace(char *buffer); 
-	int configured();
+	int configured(void);
 	void timeout_cb( GtkWidget *widget, GtkWidget *spin );
 	static int http_get_to_file(gchar *a_host, gint a_port, 
 				gchar *a_resource, FILE *a_file);
-	int http_got();
-	void properties_save( char *path) ;
+	int http_got(void);
+	void properties_save(char *path) ;
 	static void destroy_applet(GtkWidget *widget, gpointer data) ;
 	char *getSymsFromClist(GtkWidget *clist) ;
 
+	char *splitPrice(char *data);
+	char *splitChange(char *data);
 
 	/* FOR COLOR */
 
-	void updateOutput() ;
-	static void reSetOutputArray() ;
+	static void updateOutput(void) ;
+	static void reSetOutputArray(void) ;
 	static void setOutputArray(char *param1) ;
 	static void setColorArray(int theColor) ;
 	void setup_colors(void);
@@ -153,7 +155,7 @@
 	/* end font funcs and vars */
 
 	/*-----------------------------------------------------------------*/
-	gint applet_save_session(GtkWidget *widget, char *privcfgpath, 
+	static gint applet_save_session(GtkWidget *widget, char *privcfgpath, 
 				char *globcfgpath) {
 		properties_save(privcfgpath);
 		return FALSE;
@@ -161,7 +163,7 @@
 
 
 	/*-----------------------------------------------------------------*/
-	void load_fonts()
+	static void load_fonts()
 	{
 		if (new_font != NULL) {
 			if (whichlabel == 1)
@@ -200,7 +202,19 @@
 	}
 
 	/*-----------------------------------------------------------------*/
-	void properties_load( char *path) {
+	static void updateOutput(void) {
+		if ( http_got() == -1 || !(configured()) ) {  
+			reSetOutputArray();
+			fprintf(stderr, "No data!\n");
+			setOutputArray("No data available or properties not set");
+		}
+	}
+
+
+
+
+	/*-----------------------------------------------------------------*/
+	static void properties_load( char *path) {
 
 
 		gnome_config_push_prefix (path);
@@ -241,7 +255,7 @@
 
 
 	/*-----------------------------------------------------------------*/
-	void properties_save( char *path) {
+	void properties_save(char *path) {
 
 		gnome_config_push_prefix (path);
 		gnome_config_set_string( "gtik/tik_syms", props.tik_syms );
@@ -263,7 +277,7 @@
 
 
 	/*-----------------------------------------------------------------*/
-	void properties_set() {
+	static void properties_set (gboolean update) {
 		if (!strcmp(props.buttons,"yes")) {
 			gtk_widget_show(leftButton);
 			gtk_widget_show(rightButton);
@@ -275,17 +289,23 @@
 
 		setup_colors();		
 		load_fonts();
-		updateOutput();
+		if (update)
+			updateOutput();
 	}
 
 
 	/*-----------------------------------------------------------------*/
-	char * extractText(const char *line) {
+	static char *extractText(const char *line) {
 
 		int  i=0;
 		int  j=0;
 		static char Text[256]="";
 
+		if (line == NULL) {
+			Text[0] = '\0';
+			return Text;
+		}
+
 		while (i < (strlen(line) -1)) {
 			if (line[i] != '>')
 				i++;
@@ -309,7 +329,7 @@
 	}
 
 	/*-----------------------------------------------------------------*/
-	char * parseQuote(FILE *CONFIG, char line[512]) {
+	static char *parseQuote(FILE *CONFIG, char line[512]) {
 		
 		char symbol[512];
 		char buff[512];
@@ -500,12 +520,9 @@
 		int retVar;
 		FILE *local_file;
 
-		char tmpBuff[256];
-		memset(tmpBuff,0,sizeof(tmpBuff));
+		char *tmpBuff;
 
-		strcat(tmpBuff,"/q?s=");
-		strcat(tmpBuff, props.tik_syms);
-		strcat(tmpBuff,"&d=v2");
+		tmpBuff = g_strconcat ("/q?s=", props.tik_syms, "&d=v2", NULL);
 
 		retVar = 0;
 
@@ -515,6 +532,8 @@
 
 		fclose(local_file);
 
+		g_free (tmpBuff);
+
 		return retVar;
 	}
 
@@ -523,7 +542,7 @@
 
 
 	/*-----------------------------------------------------------------*/
-	gint expose_event (GtkWidget *widget,GdkEventExpose *event) {
+	static gint expose_event (GtkWidget *widget,GdkEventExpose *event) {
 
 		gdk_draw_pixmap(widget->window,
 		widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
@@ -558,7 +577,7 @@
 
 
 	/*-----------------------------------------------------------------*/
-	gint Repaint (gpointer data) {
+	static gint Repaint (gpointer data) {
 		GtkWidget* drawing_area = (GtkWidget *) data;
 		GdkRectangle update_rect;
 		int	comp;
@@ -700,17 +719,17 @@
 
 
 	/*-----------------------------------------------------------------*/
-	void refresh_cb(AppletWidget *widget, gpointer data) {
+	static void refresh_cb(AppletWidget *widget, gpointer data) {
 		updateOutput();
 	}
 
 
 	/*-----------------------------------------------------------------*/
-	void zipLeft(GtkWidget *widget, gpointer data) {
+	static void zipLeft(GtkWidget *widget, gpointer data) {
 		gchar *current;
 		gint i;
 
-		current = strdup(props.scroll);
+		current = g_strdup(props.scroll);
 		props.scroll = g_strdup("right2left");
 		for (i=0;i<151;i++) {
 			Repaint((gpointer)drawing_area);
@@ -720,11 +739,11 @@
 	}
 
 	/*-----------------------------------------------------------------*/
-	void zipRight(GtkWidget *widget, gpointer data) {
+	static void zipRight(GtkWidget *widget, gpointer data) {
 		gchar *current;
 		gint i;
 
-		current = strdup(props.scroll);
+		current = g_strdup(props.scroll);
 		props.scroll = g_strdup("left2right");
 		for (i=0;i<151;i++) {
 			Repaint((gpointer)drawing_area);
@@ -734,13 +753,13 @@
 	}
 
 	/*-----------------------------------------------------------------*/
-	void changed_cb(GnomePropertyBox * pb, gpointer data) {
+	static void changed_cb(GnomePropertyBox * pb, gpointer data) {
 		gnome_property_box_changed(GNOME_PROPERTY_BOX(pb));
 	}
 
 	/*-----------------------------------------------------------------*/
 
-	void selected_cb(GtkCList *clist,gint row, gint column, 
+	static void selected_cb(GtkCList *clist,gint row, gint column, 
 				GdkEventButton *event, gpointer data) {
 		GtkWidget *button;
 
@@ -749,7 +768,7 @@
 	}
 
 	/*-----------------------------------------------------------------*/
-	void toggle_output_cb(GtkWidget *widget, gpointer data) {
+	static void toggle_output_cb(GtkWidget *widget, gpointer data) {
 		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
 			strcpy(poutput,"nochange");
 		else
@@ -758,7 +777,7 @@
 	}
 
 	/*-----------------------------------------------------------------*/
-	void toggle_scroll_cb(GtkWidget *widget, gpointer data) {
+	static void toggle_scroll_cb(GtkWidget *widget, gpointer data) {
 		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
 			strcpy(scroll,"left2right");
 		else
@@ -768,7 +787,7 @@
 
 
 	/*-----------------------------------------------------------------*/
-	void toggle_arrows_cb(GtkWidget *widget, gpointer data) {
+	static void toggle_arrows_cb(GtkWidget *widget, gpointer data) {
 		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
 			strcpy(arrows,"arrows");
 		else
@@ -777,7 +796,7 @@
 	}
 
 	/*-----------------------------------------------------------------*/
-	void toggle_buttons_cb(GtkWidget *widget, gpointer data) {
+	static void toggle_buttons_cb(GtkWidget *widget, gpointer data) {
 		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
 			strcpy(buttons,"yes");
 		else
@@ -826,21 +845,21 @@
 			props.output = g_strdup(poutput);
 		}
 		properties_save(APPLET_WIDGET(applet)->privcfgpath);
-		properties_set();
+		properties_set(TRUE);
 	}
 
 
 
-
+#if 0
 	/*-----------------------------------------------------------------*/
-	gint destroy_cb( GtkWidget *widget, void *data ) {
+	static gint destroy_cb( GtkWidget *widget, void *data ) {
 		pb = NULL;
 		return FALSE;
 	}
-
+#endif
 
 	/*-----------------------------------------------------------------*/
-        gint font_selector( GtkWidget *widget, void *data ) {
+        static gint font_selector( GtkWidget *widget, void *data ) {
                 GtkWidget *tmpWidget;
                 GtkFontSelectionDialog *fontDialog;
 
@@ -871,7 +890,7 @@
 	}
 
         /*-----------------------------------------------------------------*/
-	gint font2_cb(GtkWidget *widget, gpointer data) {
+	static gint font2_cb(GtkWidget *widget, gpointer data) {
 		whichlabel = 2;
 		font_selector(widget,data);
 		return FALSE;
@@ -901,12 +920,15 @@
 	char *getSymsFromClist(GtkWidget *clist) {
 		GList *selection;
 		char *symbol;
-		char symlist[256]="";
+		char *ret;
+		GString *symlist;
 		gint row;
 
 		gtk_clist_freeze(GTK_CLIST(clist));
 		gtk_clist_select_all(GTK_CLIST(clist));
 
+		symlist = g_string_new (NULL);
+
 		selection = GTK_CLIST(clist)->selection;
 
 		while (selection) {
@@ -914,40 +936,48 @@
 			selection=selection->next;
 			gtk_clist_get_text(GTK_CLIST(clist),row,0,&symbol);
 
+			symbol = g_strdup (symbol);
+
+			/* XXX: couldn't this be just g_strstrip ????
+			 * -George */
 			removeSpace(symbol);
 
-			if (!strcmp(symlist,""))
-				strcpy(symlist,symbol);
-			else {
-				strcat(symlist,"+");
-				strcat(symlist,symbol);
+			if (strcmp(symlist->str,"") != 0) {
+				g_string_append (symlist, "+");
 			}
+
+			g_string_append (symlist, symbol);
+
+			g_free (symbol);
 		}
 		gtk_clist_thaw(GTK_CLIST(clist));
-		return(strdup(symlist));
+
+		ret = symlist->str;
+		g_string_free (symlist, FALSE);
+		return ret;
 	}
 
-	void populateClist(GtkWidget *clist) {
+	static void populateClist(GtkWidget *clist) {
 	
 		gchar *symbol[1];
 		gchar *syms;
 		gchar *temp;
 
-		syms = strdup(props.tik_syms);
+		syms = g_strdup(props.tik_syms);
 
 		if ((temp=strtok(syms,"+")))
-			symbol[0] = strdup(temp);
+			symbol[0] = g_strdup(temp);
 
 		while (symbol[0]) {
 			gtk_clist_append(GTK_CLIST(clist),symbol);
 			if ((temp=strtok(NULL,"+")))
-				symbol[0] = strdup(temp);
+				symbol[0] = g_strdup(temp);
 			else
 				symbol[0]=NULL;
 		}
 
 		if ((temp=strtok(NULL,""))) {
-			symbol[0] = strdup(temp);
+			symbol[0] = g_strdup(temp);
 			gtk_clist_append(GTK_CLIST(clist),symbol);
 		}
 				
@@ -957,38 +987,56 @@
 
 	/* Thanks to Mike Oliphant for inspiration. */
 
-	static void addToClist(GtkWidget *widget, gpointer data) {
-		gchar *newsymbol[1];
-		gint row;
+	static void addToClist(GtkWidget *widget_unused, gpointer entry) {
+		char *symbols, *symbol_start, *symbol_end;
+		gint row = -1;
 		GtkWidget *clist;
 
-		clist = GTK_WIDGET(gtk_object_get_data(GTK_OBJECT(widget),
+		clist = GTK_WIDGET(gtk_object_get_data(GTK_OBJECT(entry),
 							"clist"));
 
-		newsymbol[0] = gtk_entry_get_text(GTK_ENTRY(widget));
-		row = gtk_clist_append(GTK_CLIST(clist),newsymbol);
-		gtk_entry_set_text(GTK_ENTRY(widget),"");
-		gtk_clist_moveto(GTK_CLIST(clist),row,0,0,0);
+		symbols = g_strdup(gtk_entry_get_text(GTK_ENTRY(entry)));
+		symbol_start = symbol_end = symbols;
 
+		while (*symbol_end) {
+			if (*symbol_end == ' ') {
+				*symbol_end = '\0';
+				if (symbol_start != symbol_end)
+					row = gtk_clist_append(GTK_CLIST(clist),&symbol_start);
+				symbol_start = symbol_end + 1;
+			}
+			symbol_end++;
+		}
+		if (symbol_start != symbol_end)
+			row = gtk_clist_append(GTK_CLIST(clist),&symbol_start);
+
+		gtk_entry_set_text(GTK_ENTRY(entry),"");
+		if (row != -1)
+			gtk_clist_moveto(GTK_CLIST(clist),row,0,0,0);
+		g_free(symbols);
 	}
 
 	static void remFromClist(GtkWidget *widget, gpointer data) {
-		GList *selection;
+		GList *selection, *seliter;
 		gint row;
 		GtkWidget *clist;
 
 		clist = GTK_WIDGET(gtk_object_get_data(GTK_OBJECT(widget),
 							"clist"));
-		selection=GTK_CLIST(clist)->selection;
+		selection = g_list_copy (GTK_CLIST(clist)->selection);
 
-		while(selection) {
-			row=GPOINTER_TO_INT(selection->data);
-			selection = selection->next;
+		seliter = selection;
+
+		while(seliter != NULL) {
+			row=GPOINTER_TO_INT(seliter->data);
+			seliter = seliter->next;
 			gtk_clist_remove(GTK_CLIST(clist),row);
 		}
+
+		g_list_free (selection);
 	}
 
-	GtkWidget *symbolManager() { 
+	static GtkWidget *symbolManager() { 
 		GtkWidget *vbox;
 		GtkWidget *mainhbox;
 		GtkWidget *hbox;
@@ -1005,7 +1053,7 @@
 		gtk_clist_column_titles_passive(GTK_CLIST(clist));
 		gtk_widget_set_usize(clist,100,-1);
 		gtk_clist_set_column_width(GTK_CLIST(clist),0,60);
-		gtk_clist_set_reorderable(GTK_CLIST(clist),FALSE);
+		gtk_clist_set_reorderable(GTK_CLIST(clist),TRUE);
 		gtk_signal_connect_object(GTK_OBJECT(clist),"drag_drop",
 				GTK_SIGNAL_FUNC(changed_cb),GTK_OBJECT(pb));
 
@@ -1027,9 +1075,16 @@
 		gtk_object_set_data(GTK_OBJECT(entry),"clist",(gpointer)clist);
 		gtk_box_pack_start(GTK_BOX(hbox),entry,TRUE,TRUE,0);
 		gtk_signal_connect(GTK_OBJECT(entry),"activate",
-					GTK_SIGNAL_FUNC(addToClist),NULL);
+					GTK_SIGNAL_FUNC(addToClist), entry);
 		gtk_signal_connect_object(GTK_OBJECT(entry),"activate",
 				GTK_SIGNAL_FUNC(changed_cb),GTK_OBJECT(pb));
+		
+		button = gtk_button_new_with_label(_("Add"));
+		gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
+		gtk_signal_connect(GTK_OBJECT(button),"clicked",
+					GTK_SIGNAL_FUNC(addToClist), entry);
+		gtk_signal_connect_object(GTK_OBJECT(button),"clicked",
+				GTK_SIGNAL_FUNC(changed_cb),GTK_OBJECT(pb));
 
 		gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 
@@ -1261,6 +1316,16 @@
 
 
 
+	/*-----------------------------------------------------------------*/
+	/* Do the first update in an idle since we block (UGLY UGLY UGLY)
+	 * and thus this is at least marginally better behaviour since the
+	 * user will at least see something on the screen */
+	static gboolean
+	first_update (gpointer data)
+	{
+		updateOutput ();
+		return FALSE;
+	}
 
 
 	/*-----------------------------------------------------------------*/
@@ -1268,14 +1333,13 @@
 		GtkWidget * vbox;
 		GtkWidget * frame;
 
-		memset(configFileName,0,sizeof(configFileName));
-		strcat(configFileName, getenv("HOME"));
-		strcat(configFileName, "/.gtik.conf");
+		configFileName = g_strconcat (g_getenv ("HOME"), "/.gtik.conf", NULL);
 
 		/* Initialize the i18n stuff */
 		bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 		textdomain (PACKAGE);
 
+
 		/* intialize, this will basically set up the applet, corba and
 		call gnome_init */
 		applet_widget_init(GTIK_APPLET_NAME, VERSION, argc, argv,
@@ -1368,7 +1432,7 @@
 
 
 		properties_load(APPLET_WIDGET(applet)->privcfgpath);
-		properties_set();
+		properties_set(FALSE);
 
 		gtk_signal_connect(GTK_OBJECT(applet),"save_session",
 		GTK_SIGNAL_FUNC(applet_save_session), NULL);
@@ -1385,6 +1449,8 @@
 			gtk_widget_show(rightButton);
 		}
 
+		g_idle_add (first_update, NULL);
+
 		/* special corba main loop */
 		applet_widget_gtk_main ();
 
@@ -1393,18 +1459,6 @@
 
 
 
-	/*-----------------------------------------------------------------*/
-	void updateOutput() {
-		if ( http_got() == -1 || !(configured()) ) {  
-			reSetOutputArray();
-			fprintf(stderr, "No data!\n");
-			setOutputArray("No data available or properties not set");
-		}
-	}
-
-
-
-
 /* JHACK */
 	/*-----------------------------------------------------------------*/
 	static void destroy_applet(GtkWidget *widget, gpointer data) {
@@ -1488,8 +1542,8 @@
 			var4[0] = '(';
 		}
 		else {
-			var3 = strdup(_("(No"));
-			var4 = strdup(_("Change "));
+			var3 = g_strdup(_("(No"));
+			var4 = g_strdup(_("Change "));
 		}
 
 		sprintf(buff2,"%s %s)",var3,var4);
@@ -1582,7 +1636,9 @@
 		int i;
 		int j;
 		int len;
-		char buff[strlen(buffer)+1];
+		char *buff;
+
+		buff = g_new (char, strlen(buffer)+1);
 		
 		j = 0;
 		if(strlen(buffer) > 1) {
@@ -1612,6 +1668,8 @@
 			}
 			memset(buff,0,sizeof(buff));
 		}
+
+		g_free (buff);
 	}
 
 
