@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c,v 1.5 2000/01/28 21:20:25 tgil Exp $ */
+/* $Id: gweather-dialog.c,v 1.8 2000/12/08 05:05:42 jleach Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -85,15 +85,16 @@ void gweather_dialog_create (void)
   GtkWidget *radar_vbox;
   GtkWidget *radar_link_btn;
   GtkWidget *radar_link_alignment;
-  GtkWidget *forecast_scroll;
-  GtkObject *forecast_adj;
   GtkWidget *forecast_hbox;
   GtkWidget *weather_action_area;
   GtkWidget *close_button;
+  GtkWidget *ebox;
+  GtkWidget *scrolled_window;
 
   g_return_if_fail(gweather_dialog == NULL);
 
   gweather_dialog = gnome_dialog_new (_("GNOME Weather"), NULL);
+
   if (gweather_pref.radar_enabled)
       gtk_widget_set_usize (gweather_dialog, 570, 440);
   else
@@ -298,15 +299,16 @@ void gweather_dialog_create (void)
   forecast_hbox = gtk_hbox_new(FALSE, 0);
   gtk_widget_show (forecast_hbox);
 
-  forecast_adj = gtk_adjustment_new(0, 0, 0, 0, 0, 0);
+  scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
+				  GTK_POLICY_AUTOMATIC,
+				  GTK_POLICY_AUTOMATIC);
 
-  forecast_text = gtk_text_new (NULL, GTK_ADJUSTMENT (forecast_adj));
+  forecast_text = gtk_text_new (NULL, NULL);
+  gtk_container_add (GTK_CONTAINER (scrolled_window), forecast_text);
   gtk_widget_show (forecast_text);
-  gtk_box_pack_start (GTK_BOX (forecast_hbox), forecast_text, TRUE, TRUE, 0);
-
-  forecast_scroll = gtk_vscrollbar_new (GTK_ADJUSTMENT (forecast_adj));
-  gtk_widget_show (forecast_scroll);
-  gtk_box_pack_start (GTK_BOX (forecast_hbox), forecast_scroll, FALSE, FALSE, 0);
+  gtk_widget_show (scrolled_window);
+  gtk_box_pack_start (GTK_BOX (forecast_hbox), scrolled_window, TRUE, TRUE, 0);
 
   gtk_container_add (GTK_CONTAINER (weather_notebook), forecast_hbox);
 
@@ -320,9 +322,24 @@ void gweather_dialog_create (void)
       gtk_container_add (GTK_CONTAINER (weather_notebook), radar_vbox);
       gtk_container_set_border_width (GTK_CONTAINER (radar_vbox), 6);
 
+
+      /* PUSH */
+      gtk_widget_push_visual (gdk_rgb_get_visual ());
+      gtk_widget_push_colormap (gdk_rgb_get_cmap ());
+
+      ebox = gtk_event_box_new ();
+      gtk_widget_show (ebox);
+      gtk_box_pack_start (GTK_BOX (radar_vbox), ebox, FALSE, FALSE, 0);
+
+
       radar_pixmap = gtk_pixmap_new (pixmap, mask);  /* Tmp hack */
       gtk_widget_show (radar_pixmap);
-      gtk_box_pack_start (GTK_BOX (radar_vbox), radar_pixmap, FALSE, FALSE, 0);
+      gtk_container_add (GTK_CONTAINER (ebox), radar_pixmap);
+
+      /* POP */
+      gtk_widget_pop_colormap ();
+      gtk_widget_pop_visual ();
+
 
       radar_link_alignment = gtk_alignment_new (0.5, 0.5, 0, 0);
       gtk_widget_show (radar_link_alignment);
@@ -382,9 +399,11 @@ void gweather_dialog_display_toggle (void)
 
 void gweather_dialog_update (void)
 {
-    gchar *forecast;
+    const gchar *forecast;
 
-    g_return_if_fail(gweather_info != NULL);
+    /* Check for parallel network update in progress */
+    if(gweather_info == NULL)
+    	return;
 
     if (!gweather_dialog)
         return;
